==> siag_3.1.22.orig.tar.gz: siag-3.1.22/xpw/app-defaults.h <==
"Pw.geometry:			600x400",
"Pw*combo_viewport.allowHoriz:	False",
"Pw*submenu.translations:      #override                       \\n\
        :<EnterWindow>:         highlight()                     \\n\
        :<LeaveWindow>:         MenuPopdown() unhighlight()     \\n\
        :<BtnMotion>:           highlight()                     \\n\
        :<BtnUp>:               popdown-submenu() notify() unhighlight()",
"Pw*topbox.xLayout:	100%",
"Pw*topbox.yLayout:	30 30 30 30 100% 30",
"Pw*topbox*List*background:	white",
"Pw*textframe.topShadowContrast:	-40",
"Pw*textframe.bottomShadowContrast:	-20",
"Pw*formatframe.topShadowContrast:	-40",
"Pw*formatframe.bottomShadowContrast:	-20",
"Pw*formatframe.shadowWidth:		1",
"Pw*formatframe.height:		20",
"Pw*formatframe.borderWidth:		4",
"Pw*formatframe.borderColor:		grey",
"Pw*Box.handle.width:		9",
"Pw*Box.handle.height:		28",
"Pw*Box.handle.label:",
"Pw*frame.shadowWidth:			1",
"Pw*menubar.shadowWidth:			1",
"Pw*menubar.gridy:			0",
"Pw*menubox.SiagMenuButton.shadowWidth:	0",
"Pw*menubox.SiagMenuButton.internalHeight:	6",
"Pw*menubox.MenuButton.shadowWidth:	0",
"Pw*menubox.MenuButton.internalHeight:	6",
"Pw*menubox.orientation:			horizontal",
"Pw*menubox.borderWidth:			0",
"Pw*menubox.vSpace:			0",
"Pw*menubox.hSpace:			0",
"Pw*toolbar.shadowWidth:			1",
"Pw*toolbar.gridy:			1",
"Pw*toolbox.Toggle.shadowWidth:		0",
"Pw*toolbox.Command.shadowWidth:		0",
"Pw*toolbox.orientation:			horizontal",
"Pw*toolbox.borderWidth:			0",
"Pw*toolbox.vSpace:			0",
"Pw*toolbox.hSpace:			0",
"Pw*formatbar.shadowWidth:		1",
"Pw*formatbar.gridy:			2",
"Pw*formatbox.vSpace:			0",
"Pw*formatbox.hSpace:			0",
"Pw*formatbox.Toggle.shadowWidth:	0",
"Pw*formatbox.Command.shadowWidth:	0",
"Pw*formatbox.orientation:		horizontal",
"Pw*formatbox.borderWidth:		0",
"Pw*textbox.borderWidth:			0",
"Pw*textbox.gridy:			3",
"Pw*textbox.xLayout:			4 100% 4",
"Pw*textbox.yLayout:			4 100% 4",
"Pw*label1.font:				-*-helvetica-medium-r-*-12-*",
"Pw*label1.gridx:			1",
"Pw*label1.gridy:			1",
"Pw*gridpane.borderWidth:		0",
"Pw*gridpane.gridy:			4",
"Pw*statusbox.borderWidth:		0",
"Pw*statusbox.gridy:			5",
"Pw*statusbox.xLayout:			4 100% 4 100 4",
"Pw*statusbox.yLayout:			4 100% 4",
"Pw*label2.font:				-*-helvetica-medium-r-*-12-*",
"Pw*label2.shadowWidth:			1",
"Pw*label2.gridx:			1",
"Pw*label2.gridy:			1",
"Pw*label3.font:				-*-helvetica-medium-r-*-12-*",
"Pw*label3.shadowWidth:			1",
"Pw*label3.gridx:			3",
"Pw*label3.gridy:			1",
"Pw*viewport.xLayout:			25 25 50% 50% 15",
"Pw*viewport.yLayout:			20 100% 15",
"Pw*rulerframe.gridWidth:		4",
"Pw*rulerframe.shadowWidth:		1",
"Pw*rulerframe.shadowType:		Solid",
"Pw*ruler.borderWidth:			0",
"Pw*grid.gridy:				1",
"Pw*grid.gridWidth:			4",
"Pw*grid.background:			white",
"Pw*grid.borderWidth:			0",
"Pw*vscroll.gridx:			4",
"Pw*vscroll.gridHeight:			2",
"Pw*vscroll.orientation:			vertical",
"Pw*tabl.gridy:				2",
"Pw*tabl.label:				<<",
"Pw*tabr.label:				>>",
"Pw*tabr.gridx:				1",
"Pw*tabr.gridy:				2",
"Pw*tab.gridx:				2",
"Pw*tab.gridy:				2",
"Pw*hscroll.gridx:			3",
"Pw*hscroll.gridy:			2",
"Pw*hscroll.orientation:			horizontal",
"Pw*vsep.width:				2",
"Pw*vsep.height:				24",
"Pw*vsep.borderWidth:			2",
"Pw*vsep.borderColor:			grey",
"Pw*vsep.shadowWidth:			1",
"Pw*vsep.topShadowContrast:		-40",
"Pw*vsep.bottomShadowContrast:		-20",
"Pw*topbox.translations:		#override			\\n\
	<Key>F1:		siaghelp(pw.html)",
"Pw*toolbar_command.translations:	#override	\\n\
	<Enter>:	siag-highlight(1)\\n\
	<Leave>:	siag-unhighlight(0)",
"Pw*toolbar_toggle.translations:	#override	\\n\
	<Enter>:	siag-highlight(1 1)\\n\
	<Leave>:	siag-unhighlight(0 1)",
"Pw*grid.translations:\
	:<Btn1Down>:			grid-button(point)		\\n\
	:<Btn1Motion>:			grid-button(adjust)		\\n\
	:<Btn2Down>:			grid-button(paste)		\\n\
	Shift<Btn3Down>:		grid-button(select)		\\n\
	:<Btn3Down>:			popup-shortcuts() \\n\
	:<Key>Home:			execute(beginning-of-line)	\\n\
	Ctrl<Key>a:			execute(beginning-of-line)	\\n\
	:<Key>End:			execute(end-of-line)		\\n\
	Ctrl<Key>e:			execute(end-of-line)		\\n\
	Ctrl<Key>space:			execute(set-mark-command)	\\n\
	<Key>space:			self-insert-char()		\\n\
	:<Key>Left:			execute(backward-char)		\\n\
	Ctrl<Key>b:			execute(backward-char)		\\n\
	:<Key>Delete:			execute(delete-char)		\\n\
	Ctrl<Key>d:			execute(delete-char)		\\n\
	:<Key>BackSpace:		execute(delete-char-backward)	\\n\
	:<Key>Right:			execute(forward-char)		\\n\
	Ctrl<Key>f:			execute(forward-char)		\\n\
	:<Key>Down:			execute(next-line)		\\n\
	Ctrl<Key>n:			execute(next-line)		\\n\
	Ctrl<Key>o:			execute(split-line)		\\n\
	:<Key>Return:			execute(newline)		\\n\
	Ctrl<Key>k:			execute(kill-line)		\\n\
	Ctrl<Key>l:			execute(recenter)		\\n\
	Ctrl<Key>x,Ctrl<Key>f:		execute(load-buffer)		\\n\
	Ctrl<Key>x,Ctrl<Key>d:		execute(debug-format)		\\n\
	:<Key>Up:			execute(previous-line)		\\n\
	Ctrl<Key>p:			execute(previous-line)		\\n\
	Ctrl<Key>x,Ctrl<Key>c:		execute(quit-program)		\\n\
	Ctrl<Key>x,Ctrl<Key>s:		execute(save-buffer)		\\n\
	Ctrl<Key>x,Ctrl<Key>w:		execute(save-buffer-as)		\\n\
	Ctrl<Key>x,Ctrl<Key>x:		execute(exchange-point-and-mark)\\n\
	Ctrl<Key>x,Ctrl<Key>space: 	execute(set-block)		\\n\
	Meta<Key>x:			execute(execute-extended-command)\\n\
	:Meta<Key>less:			execute(beginning-of-buffer)	\\n\
	:Meta<Key>greater:		execute(end-of-buffer)		\\n\
	:<Key>Page_Up:			execute(scroll-up)		\\n\
	Meta<Key>v:			execute(scroll-up)		\\n\
	:<Key>Page_Down:		execute(scroll-down)		\\n\
	Ctrl<Key>v:			execute(scroll-down)		\\n\
	Ctrl<Key>w:			execute(delete-block)		\\n\
	Ctrl<Key>x,<Key>question: 	execute(what-cursor-position)	\\n\
	<Key>question:			self-insert-char()		\\n\
	Ctrl<Key>x,<Key>k:		execute(kill-buffer)		\\n\
	<Key>k:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>b:		execute(switch-to-buffer)	\\n\
	<Key>b:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>2:		execute(split-window-vertically)\\n\
	<Key>2:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>1:		execute(delete-other-windows)	\\n\
	<Key>1:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>0:		execute(delete-window)		\\n\
	<Key>0:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>o:		execute(other-window)		\\n\
	<Key>o:				self-insert-char()		\\n\
	:<Key>F1:			execute(help-contents)		\\n\
	Ctrl<Key>h,<Key>c:		execute(help-contents)		\\n\
	<Key>c:				self-insert-char()		\\n\
	:<Key>F4:			execute(more complicated test)	\\n\
	:<Key>a:			self-insert-char()		\\n\
	:<Key>A:			self-insert-char()		\\n\
	<Key>:				self-insert-char()",
"Pw*plugin-parent.translations:\
	<Btn1Down>:			plugin-resize()	\\n\
	:<Motion>:			plugin-cursor()",
"Pw*font_pshell.x:			80",
"Pw*font_pshell.y:			80",
"Pw*font_okbutton.width:			80",
"Pw*font_cancelbutton.width:		80",
"Pw*alert*borderWidth:			0",
"Pw*alert*topbox.orientation:		vertical",
"Pw*alert*buttonbox.orientation:		horizontal",
"Pw*listshell*borderWidth:		0",
"Pw*listshell*topbox.orientation:	horizontal",
"Pw*listshell*listbox.orientation:	vertical",
"Pw*listshell*viewport.borderWidth:	1",
"Pw*listshell*buttonbox.orientation:	vertical",
"Pw*form_shell*MenuButton.shadowWidth:	1",

==> siag_3.5.1.orig.tar.gz: siag-3.5.1/xpw/app-defaults.h <==
"Pw.geometry:			640x420",
"Pw*combo_viewport.allowHoriz:	False",
"Pw*topbox.xLayout:	100%",
"Pw*topbox.yLayout:	30 30 30 100% 30",
"Pw*topbox*List*background:	white",
"Pw*textframe.topShadowContrast:	-40",
"Pw*textframe.bottomShadowContrast:	-20",
"Pw*format_command.shadowWidth:		1",
"Pw*format_command.borderWidth:		4",
"Pw*frame.shadowWidth:			1",
"Pw*menubar.shadowWidth:			1",
"Pw*menubar.gridy:			0",
"Pw*menubox.NwsMenuButton.shadowWidth:	0",
"Pw*menubox.NwsMenuButton.internalHeight:	6",
"Pw*menubox.orientation:			horizontal",
"Pw*menubox.borderWidth:			0",
"Pw*menubox.vSpace:			0",
"Pw*menubox.hSpace:			0",
"Pw*toolbar.shadowWidth:			1",
"Pw*toolbar.gridy:			1",
"Pw*toolbox.Toggle.shadowWidth:		0",
"Pw*toolbox.Command.shadowWidth:		0",
"Pw*toolbox.orientation:			horizontal",
"Pw*toolbox.borderWidth:			0",
"Pw*toolbox.vSpace:			0",
"Pw*toolbox.hSpace:			0",
"Pw*formatbar.shadowWidth:		1",
"Pw*formatbar.gridy:			2",
"Pw*formatbox.vSpace:			0",
"Pw*formatbox.hSpace:			0",
"Pw*formatbox.Toggle.shadowWidth:	0",
"Pw*formatbox.Command.shadowWidth:	0",
"Pw*formatbox.orientation:		horizontal",
"Pw*formatbox.borderWidth:		0",
"Pw*gridpane.borderWidth:		0",
"Pw*gridpane.gridy:			3",
"Pw*statusbox.borderWidth:		0",
"Pw*statusbox.gridy:			4",
"Pw*statusbox.xLayout:			4 100% 4 150 4 100 4",
"Pw*statusbox.yLayout:			4 100% 4",
"Pw*label1.shadowWidth:			1",
"Pw*label1.gridx:			3",
"Pw*label1.gridy:			1",
"Pw*label2.shadowWidth:			1",
"Pw*label2.gridx:			1",
"Pw*label2.gridy:			1",
"Pw*label3.shadowWidth:			1",
"Pw*label3.gridx:			5",
"Pw*label3.gridy:			1",
"Pw*viewport.xLayout:			25 25 50% 50% 17",
"Pw*viewport.yLayout:			25 100% 17",
"Pw*ruler.gridWidth:			4",
"Pw*ruler.borderWidth:			0",
"Pw*ruler.font:				-*-helvetica-medium-r-*-10-*",
"Pw*grid.gridy:				1",
"Pw*grid.gridWidth:			4",
"Pw*grid.background:			white",
"Pw*grid.borderWidth:			0",
"Pw*grid.richtextDelay:			50",
"Pw*vscroll.gridx:			4",
"Pw*vscroll.gridHeight:			2",
"Pw*vscroll.orientation:			vertical",
"Pw*tabl.gridy:				2",
"Pw*tabl.label:				<<",
"Pw*tabr.label:				>>",
"Pw*tabr.gridx:				1",
"Pw*tabr.gridy:				2",
"Pw*tab.gridx:				2",
"Pw*tab.gridy:				2",
"Pw*hscroll.gridx:			3",
"Pw*hscroll.gridy:			2",
"Pw*hscroll.orientation:			horizontal",
"Pw*vsep.width:				2",
"Pw*vsep.height:				24",
"Pw*vsep.borderWidth:			2",
"Pw*vsep.borderColor:			grey",
"Pw*vsep.shadowWidth:			1",
"Pw*vsep.topShadowContrast:		-40",
"Pw*vsep.bottomShadowContrast:		-20",
"Pw*topbox.translations:		#override			\\n\
	<Key>F1:		siaghelp(pw.html)",
"Pw*toolbar_command.translations:	#override	\\n\
	<Enter>:	siag-highlight(1)\\n\
	<Leave>:	siag-unhighlight(0)",
"Pw*toolbar_toggle.translations:	#override	\\n\
	<Enter>:	siag-highlight(1 1)\\n\
	<Leave>:	siag-unhighlight(0 1)",
"Pw*grid.translations:		#override	\\n\
	:<Btn1Down>:			grid-button(point)		\\n\
	:<Btn1Motion>:			grid-button(adjust)		\\n\
	:<Btn2Down>:			grid-button(paste)		\\n\
	Shift<Btn3Down>:		grid-button(select)		\\n\
	:<Btn3Down>:			popup-shortcuts() \\n\
	:<Key>Home:			execute(beginning-of-line)	\\n\
	Ctrl<Key>a:			execute(beginning-of-line)	\\n\
	:<Key>End:			execute(end-of-line)		\\n\
	Ctrl<Key>e:			execute(end-of-line)		\\n\
	Ctrl<Key>space:			execute(set-mark-command)	\\n\
	<Key>space:			self-insert-char()		\\n\
	:<Key>Left:			execute(backward-char)		\\n\
	Ctrl<Key>b:			execute(backward-char)		\\n\
	:<Key>Delete:			execute(delete-char)		\\n\
	Ctrl<Key>d:			execute(delete-char)		\\n\
	:<Key>BackSpace:		execute(delete-char-backward)	\\n\
	:<Key>Right:			execute(forward-char)		\\n\
	Ctrl<Key>f:			execute(forward-char)		\\n\
	:<Key>Down:			execute(next-line)		\\n\
	Ctrl<Key>n:			execute(next-line)		\\n\
	Ctrl<Key>o:			execute(split-line)		\\n\
	:<Key>Return:			execute(newline)		\\n\
	Ctrl<Key>k:			execute(kill-line)		\\n\
	Ctrl<Key>l:			execute(recenter)		\\n\
	Ctrl<Key>x,Ctrl<Key>f:		execute(load-buffer)		\\n\
	Ctrl<Key>x,Ctrl<Key>d:		execute(debug-format)		\\n\
	:<Key>Up:			execute(previous-line)		\\n\
	Ctrl<Key>p:			execute(previous-line)		\\n\
	Ctrl<Key>x,Ctrl<Key>c:		execute(quit-program)		\\n\
	Ctrl<Key>x,Ctrl<Key>s:		execute(save-buffer)		\\n\
	Ctrl<Key>x,Ctrl<Key>w:		execute(save-buffer-as)		\\n\
	Ctrl<Key>x,Ctrl<Key>x:		execute(exchange-point-and-mark)\\n\
	Ctrl<Key>x,Ctrl<Key>space: 	execute(set-block)		\\n\
	Meta<Key>x:			execute(execute-extended-command)\\n\
	:Meta<Key>less:			execute(beginning-of-buffer)	\\n\
	:Meta<Key>greater:		execute(end-of-buffer)		\\n\
	:<Key>Page_Up:			execute(scroll-up)		\\n\
	Meta<Key>v:			execute(scroll-up)		\\n\
	:<Key>Page_Down:		execute(scroll-down)		\\n\
	Ctrl<Key>v:			execute(scroll-down)		\\n\
	Ctrl<Key>w:			execute(delete-block)		\\n\
	Ctrl<Key>x,<Key>question: 	execute(what-cursor-position)	\\n\
	<Key>question:			self-insert-char()		\\n\
	Ctrl<Key>x,<Key>k:		execute(kill-buffer)		\\n\
	<Key>k:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>b:		execute(switch-to-buffer)	\\n\
	<Key>b:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>2:		execute(split-window-vertically)\\n\
	<Key>2:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>1:		execute(delete-other-windows)	\\n\
	<Key>1:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>0:		execute(delete-window)		\\n\
	<Key>0:				self-insert-char()		\\n\
	Ctrl<Key>x,<Key>o:		execute(other-window)		\\n\
	<Key>o:				self-insert-char()		\\n\
	:<Key>F1:			execute(help-contents)		\\n\
	Ctrl<Key>h,<Key>c:		execute(help-contents)		\\n\
	<Key>c:				self-insert-char()		\\n\
	:<Key>F4:			execute(more complicated test)	\\n\
	:<Key>a:			self-insert-char()		\\n\
	:<Key>A:			self-insert-char()		\\n\
	Ctrl<Key>c,Ctrl<Key>c:		execute(copy-block-to-string)	\\n\
	Ctrl<Key>c,Ctrl<Key>f:		execute(search-forward)		\\n\
	Ctrl<Key>c,Ctrl<Key>g:		execute(keyboard-quit)		\\n\
	Ctrl<Key>c,Ctrl<Key>n:		execute(new-buffer)		\\n\
	Ctrl<Key>c,Ctrl<Key>o:		execute(load-buffer)		\\n\
	Ctrl<Key>c,Ctrl<Key>p:		execute(print)			\\n\
	Ctrl<Key>c,Ctrl<Key>q:		execute(quit-program)		\\n\
	Ctrl<Key>c,Ctrl<Key>s:		execute(save-buffer-as)		\\n\
	Ctrl<Key>c,Ctrl<Key>v:		execute(paste-block-from-string)\\n\
	Ctrl<Key>c,Ctrl<Key>w:		execute(kill-buffer)		\\n\
	Ctrl<Key>c,Ctrl<Key>x:		execute(cut-block-to-string)	\\n\
	Ctrl<Key>c,Ctrl<Key>z:		execute(undo-restore)		\\n\
	<Key>:				self-insert-char()",
"Pw*plugin-parent.translations:\
	<Btn1Down>:			plugin-resize()	\\n\
	:<Motion>:			plugin-cursor()",
"Pw*font_pshell.x:			80",
"Pw*font_pshell.y:			80",
"Pw*font_okbutton.width:			80",
"Pw*font_cancelbutton.width:		80",
"Pw*alert*borderWidth:			0",
"Pw*alert*topbox.orientation:		vertical",
"Pw*alert*buttonbox.orientation:		horizontal",
"Pw*listshell*borderWidth:		0",
"Pw*listshell*topbox.orientation:	horizontal",
"Pw*listshell*listbox.orientation:	vertical",
"Pw*listshell*viewport.borderWidth:	1",
"Pw*listshell*buttonbox.orientation:	vertical",
"Pw*form_shell*NwsMenuButton.shadowWidth:	1",
